@@ -1,21 +1,46 @@
 #coding:utf-8
-import threading
-import inspect
+"""
+Основные объекты библиотеки: механизмы проверки прав, экшены, паки, контроллеры, кэш контроллеров
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+"""
 import abc
-import re
+from functools import wraps
+import inspect
 import importlib
-import sys
-import time
+import threading
+import re
+import warnings
 
+from django import http
 from django.conf import settings
 from django.utils.importlib import import_module
-from django import http
 
-from django.utils.log import logger
+try:
+    from django.utils.log import logger
+except ImportError:
+    from django.utils.log import getLogger
+    logger = getLogger('django')
 
-from results import *
+from results import (
+    ActionResult,
+    PreJsonResult,
+    JsonResult,
+    HttpReadyResult,
+    TextResult,
+    XMLResult,
+    BaseContextedResult,
+    OperationResult,
+    ActionRedirectResult
+)
 
-from exceptions import *
+from exceptions import (
+    ApplicationLogicException,
+    ActionException,
+    ActionNotFoundException,
+    ActionPackNotFoundException,
+    ReinitException,
+    ActionUrlIsNotDefined
+)
 
 import utils
 
@@ -75,10 +100,53 @@ def _name_of(obj):
     return '%s.%s%s' % (package, parent, obj)
 
 
+def _cached_to(attr_name):
+    """
+    Оборачивает простые методы (без аргументов) и property getters,
+    с целью закэшировать первый полученный результат
+    """
+    def wrapper(fn):
+        @wraps(fn)
+        def inner(self):
+            if hasattr(self, attr_name):
+                result = getattr(self, attr_name)
+            else:
+                result = fn(self)
+                setattr(self, attr_name, result)
+            return result
+        return inner
+    return wrapper
+
+
+def _must_be_replaced_by(alternative):
+    """
+    Оборачивает устаревший метод таким образом,
+    что при вызове метода выводится предупреждение
+    с рекомендацией замены метода на текущую альтернативу
+    """
+    def wrapper(fn):
+        @wraps(fn)
+        def inner(self, *args, **kwargs):
+            class_name = self.__class__.__name__
+            # if '%' in alternative:
+            #     alternative = alternative % class_name
+            warnings.warn(
+                "'{clazz}.{method}' deprecated! Use '{alternative}'!".format(
+                    clazz=class_name,
+                    method=fn.func_name,
+                    alternative=alternative
+                ), FutureWarning, 2)
+            return fn(self, *args, **kwargs)
+        return inner
+    return wrapper
+
+
 #==============================================================================
 # Абстрактный механизм проверки прав и его реализация,
 # проверяющая права через механизм django.contrib.auth.models.User.has_perm
 #==============================================================================
+
+
 class AbstractPermissionChecker(object):
     """
     Абстрактный механизм проверки прав
@@ -88,8 +156,17 @@ class AbstractPermissionChecker(object):
     @abc.abstractmethod
     def has_action_permission(self, request, action, subpermission=None):
         """
-        Метод должен возвращать True, если выполнение @action
-        допустимо в контексте запроса @request
+        Метод должен возвращать True, если выполнение экшена
+        допустимо в контексте запроса
+
+        :param request: запрос
+        :type request: django.http.Request
+
+        :param action: Экшен, наличие прав на выполнение которого проверяется
+        :type action: m3_core.actions.Action
+
+        :return: Допустимость выполнения экшена в контесте запроса
+        :rtype: True или False
         """
         pass
 
@@ -97,8 +174,17 @@ class AbstractPermissionChecker(object):
     def has_pack_permission(self, request, pack, permission):
         """
         Метод должен возвращать True, если действие,
-        характеризуемое парой @pack/@permission,
-        допустимо в контексте запроса @request
+        характеризуемое парой pack/permission,
+        допустимо в контексте запроса
+
+        :param request: запрос
+        :type request: django.http.Request
+
+        :param pack: пак, для которого возвращается код доступа
+        :type pack: m3_core.actions.ActionPack
+
+        :return: Допустимость пака в контесте запроса
+        :rtype: True или False
         """
         pass
 
@@ -106,12 +192,23 @@ class AbstractPermissionChecker(object):
     def get_perm_code(action_or_pack, subpermission=None):
         '''
         Возвращает код действия, для контроля прав доступа
+
+        :param action_or_pack: экшен или пак, для которого
+            возвращается код доступа
+        :type action_or_pack: m3_core.actions.Action либо
+            m3_core.actions.ActionPack
+
+        :param basestring subpermission: код подправа
+
+        :return: код действия для контроля прав доступа
+        :rtype: basestring
         '''
-        code = action_or_pack.get_absolute_url()
+        code = _name_of(action_or_pack)
         # уберем из кода префикс системы,
         # т.к. код права должен быть относительным
         if hasattr(settings, 'ROOT_URL') and (
-                code.startswith(settings.ROOT_URL)):
+            code.startswith(settings.ROOT_URL)
+        ):
             code = code[len(settings.ROOT_URL):]
         if subpermission:
             code = '%s#%s' % (code, subpermission)
@@ -128,10 +225,7 @@ class AuthUserPermissionChecker(AbstractPermissionChecker):
     указывающего на текущего пользователя
     """
     def has_action_permission(self, request, action, subpermission=None):
-        """
-        Метод должен возвращать True, если выполнение @action
-        допустимо в контексте запроса @request
-        """
+
         # контракт
         assert isinstance(action, Action)
         assert isinstance(action.parent, ActionPack)
@@ -159,11 +253,6 @@ class AuthUserPermissionChecker(AbstractPermissionChecker):
         return result
 
     def has_pack_permission(self, request, pack, permission):
-        """
-        Метод должен возвращать True, если действие,
-        характеризуемое парой @pack/@permission,
-        допустимо в контексте запроса @request
-        """
         assert isinstance(pack, ActionPack)
         if permission:
             assert isinstance(permission, str)
@@ -205,7 +294,7 @@ class LegacyPermissionChecker(AbstractPermissionChecker):
 
     def has_action_permission(self, request, action, subpermission=None):
         '''
-        Проверка пава на выполнение действия для указанного пользователя
+        Проверка пака на выполнение действия для указанного пользователя
         '''
         assert isinstance(action.parent, ActionPack)
         # Если в наборе действий need_check_permission=True,
@@ -255,7 +344,6 @@ class LegacyPermissionChecker(AbstractPermissionChecker):
         return True
 
 
-#========================== экземпляр проверятеля прав ========================
 class LazyContainer(object):
     """
     Ленивая обёртка для объектов, указываемых в settings.
@@ -316,104 +404,65 @@ _permission_checker = LazyContainer(_permission_checker_fabric)
 
 
 #========================== ИСКЛЮЧЕНИЯ ========================================
-class ActionException(Exception):
-    def __init__(self, clazz, *args, **kwargs):
-        super(Exception, self).__init__(*args, **kwargs)
-        self.clazz = clazz
-
-
-class ActionNotFoundException(ActionException):
-    """
-    Возникает в случае, если экшен не найден ни в одном контроллере
-    """
-    def __str__(self):
-        return 'Action "%s" not registered in controller/pack' % self.clazz
-
-
-class ActionPackNotFoundException(ActionException):
-    """
-    Возникает в случае, если пак не найден ни в одном контроллере
-    """
-    def __str__(self):
-        return 'ActionPack "%s" not registered in controller/pack' % self.clazz
-
-
-class ReinitException(ActionException):
-    """
-    Возникает, если из-за неправильной структуры паков один и тот же
-    экземпляр экшена может быть повторно инициализирован неверными значениями.
-    """
-    def __str__(self):
-        return 'Trying to overwrite class "%s"' % self.clazz
-
-
-class ActionUrlIsNotDefined(ActionException):
-    """
-    Возникает если в классе экшена не задан атрибут url.
-    Это грозит тем, что контроллер не сможет найти и вызвать
-    данный экшен при обработке запросов.
-    """
-    def __str__(self):
-        return (
-            'Attribute "url" is not defined '
-            'or empty in action "%s"' % self.clazz
-        )
-
 
 #==============================================================================
 class Action(object):
-    '''
+    u"""
     Базовый класс, от которого должны наследоваться все Action'ы в системе.
     Заменяет собой классические вьюшки Django.
-    '''
+    """
 
-    # Часть адреса запроса которая однозначно определяет его принадлежность к
-    # конкретному Action'у
+    #: Часть адреса запроса которая однозначно определяет его принадлежность к
+    #: конкретному Action'у
     url = ''
 
-    # Ссылка на ActionPack к которому принадлежит данный Action
+    #: Ссылка на ActionPack к которому принадлежит данный Action
     parent = None
 
-    # Ссылка на контроллер к которому принадлежит данный Action
+    #: Ссылка на контроллер к которому принадлежит данный Action
     controller = None
 
-    # Наименование действия для отображения
+    #: Наименование действия для отображения
     verbose_name = None
 
-    # Признак обработки прав доступа,
-    # при выполнении действия (по-умолчанию отключен)
-    # Как обрабатывается этот признак - смотри в has_permission
+    #: Признак обработки прав доступа,
+    #: при выполнении действия (по-умолчанию отключен)
+    #: Как обрабатывается этот признак - смотри в has_permission
     need_check_permission = False
 
-    # Словарь внутренних прав доступа, используемых в действии
-    # ключ - код права, который совмещается с кодом действия
-    # значение - наименование права
-    # Пример: {'tab2':u'Редактирование вкладки Доп. сведения',
-    #          'work_visible':u'Просмотр сведений о работе'}
-    # Общий код права доступа будет иметь вид:
-    #     /edit#tab2 и /edit#work_visible соответственно
-    # Как обрабатывается этот список - смотри в has_sub_permission
+    #: Словарь внутренних прав доступа, используемых в действии
+    #: ключ - код права, который совмещается с кодом действия
+    #: значение - наименование права
+    #: Пример: {'tab2':u'Редактирование вкладки Доп. сведения',
+    #: 'work_visible':u'Просмотр сведений о работе'}
+    #: Общий код права доступа будет иметь вид:
+    #: /edit#tab2 и /edit#work_visible соответственно
+    #: Как обрабатывается этот список - смотри в has_sub_permission
     sub_permissions = {}
 
-    # Логический путь действия в прикладной системе.
-    # Используется только для отображения и группировки
-    # действий с одинаковым путем.
-    # Также может использоваться для создания меню.
-    # Например, путь может быть: "Справочники\Общие" или "Реестры"
+    #: Логический путь действия в прикладной системе.
+    #: Используется только для отображения и группировки
+    #: действий с одинаковым путем.
+    #: Также может использоваться для создания меню.
+    #: Например, путь может быть: "Справочники\Общие" или "Реестры"
     path = None
 
+    @_must_be_replaced_by('%s.get_perm_code')
     def get_sub_permission_code(self, sub_code):
         # метод оставлен для совместимости
         return self.get_perm_code(sub_code)
 
+    @_must_be_replaced_by('%s.has_perm')
     def has_sub_permission(self, user_obj, sub_code, request):
         # метод оставлен для совместимости
         return self.has_perm(request, sub_code)
 
+    @_must_be_replaced_by('%s.get_perm_code')
     def get_permission_code(self):
         # метод оставлен для совместимости
         return self.get_perm_code()
 
+    @_must_be_replaced_by('%s.has_perm')
     def has_permission(self, user_obj, request):
         # метод оставлен для совместимости
         return self.has_perm(request)
@@ -424,6 +473,9 @@ class Action(object):
         Интерфейсный метод проверки (под)прав экшна.
 
         Использовать ВМЕСТО has_permission/has_sub_permission
+
+        :param request: запрос
+        :type request: django.http.Request
         """
         return _permission_checker.has_action_permission(
             request, self, subpermission)
@@ -439,30 +491,52 @@ class Action(object):
     def pre_run(self, request, context):
         """
         Метод для предварительной обработки
-        входящего запроса *request* и контекста *context*,
+        входящего запроса и контекста,
         перед передачений в run().
         Если возвращает значение отличное от None,
         обработка запроса прекращается и результат
         уходит во вьюшку контроллера.
+
+        :param request: запрос
+        :type request: django.http.Request
+
+        :param context: Контекст выполнения операции, восстанавливаемый
+            из контекств
+        :type context: m3_core.actions.context.ActionContext
+
+        :return: None либо объект для обработке во вьюшке контроллера
         """
         pass
 
     def post_run(self, request, context, response):
         """
-        Метод для постобработка результата работы Action'а.
-        Принимает исходный запрос *request*,
-        результат работы run() *response*
-        и извлеченный контекст *context*.
+        Метод для постобработка результата работы экшенаа.
+
+        :param request: запрос
+        :type request: django.http.Request
+
+        :param context: Контекст выполнения операции,
+            востанавливаемый из контекств
+        :type context: m3_core.actions.context.ActionContext
+
+        :param response: результат выполнения экшена
+        :type response: наследник m3_core.actions.results.ActionResult
         """
         pass
 
     def context_declaration(self):
         """
-        Метод декларирует необходимость наличия
+        Метод объявления необходимости наличия
         определенных параметров в контексте.
+
         Должен возвращать список из экземпляров *ActionContextDeclaration*
         либо
         словарь описания контекста для *DeclarativeActionContext*
+
+        :return: описание необходимости наличия определенных параметров
+            в запросе
+        :rtype: list of m3_core.actions.context.ActionContextDeclaration либо
+            m3_core.actions.context.DeclarativeActionContext
         """
         pass
 
@@ -471,7 +545,16 @@ class Action(object):
         Обеспечивает непосредственное исполнение запроса
         (аналог views в Django).
         Обязательно должен быть перекрыт в наследнике.
-        Должен возвращать экземпляр одного из наследников *ActionResult*
+
+        :param request: запрос
+        :type request: django.http.Request
+
+        :param context: Контекст выполнения операции,
+            востанавливаемый из контекств
+        :type context: m3_core.actions.context.ActionContext
+
+        :return: результат выполнения экшена
+        :rtype: наследник m3_core.actions.results.ActionResult
         """
         raise NotImplementedError()
 
@@ -482,6 +565,9 @@ class Action(object):
         НО при условии что этот экшен используется
         ТОЛЬКО В ОДНОМ ПАКЕ И КОНТРОЛЛЕРЕ, иначе валим всех!
         Ищет перебором!
+
+        :return: полный путь до действия
+        :rtype: basestring
         '''
         url = ControllerCache.get_action_url(cls)
         if not url:
@@ -491,6 +577,9 @@ class Action(object):
     def get_packs_url(self):
         """
         Возвращает строку, полный адрес от контроллера до текущего экшена
+
+        :return: полный адрес от контроллера до текущего экшена
+        :rtype: basestring
         """
         assert isinstance(self.parent, ActionPack)
         path = []
@@ -514,7 +603,11 @@ class Action(object):
 
     @classmethod
     def get_verbose_name(cls):
-        return cls.verbose_name if cls.verbose_name else cls.__name__
+        return cls.verbose_name if cls.verbose_name else cls.get_short_name()
+
+    @classmethod
+    def get_short_name(cls):
+        return _name_of(cls)
 
 
 class ActionPack(object):
@@ -523,41 +616,28 @@ class ActionPack(object):
     Предназначен для хранения в себе других
     экшенов и паков, схожих по целям.
     '''
-    # Адрес экшенпака
     url = ''
 
-    # Ссылка на вышестоящий пакет, тот в котором зарегистрирован данный пакет
-    parent = None
+    # Адрес экшенпака
+    @classmethod
+    def get_short_name(cls):
+        """
+        Имя пака для поиска в ControllerCache
 
-    # Наименование Набора действий для отображения
-    verbose_name = None
+        :return: Имя пака
+        :rtype: basestring
+        """
+        name = cls.__dict__.get('_auto_short_name')
+        if not name:
+            name = cls._auto_short_name = _name_of(cls)
+        return name
 
-    # Признак обработки прав доступа,
-    # при выполнении дочерних действий (по-умолчанию отключен)
-    # Как обрабатывается этот признак - смотри в Action.has_permission
-    need_check_permission = False
-
-    # Словарь внутренних прав доступа, используемых в наборе действий
-    # ключ - код права, который совмещается с адресом (кодом) набора действий
-    # значение - наименование права
-    # Пример: {'edit':u'Редактирование записи'}
-    # Общий код права доступа будет иметь вид: /users#edit
-    # Как обрабатывается этот список - смотри в has_sub_permission
-    sub_permissions = {}
-
-    # Логический путь набора действий в прикладной системе.
-    # Используется только для отображения
-    # и группировке наборов с одинаковым путем.
-    # Также может использоваться для создания меню.
-    # Например, путь может быть: "Справочники\Общие" или "Реестры"
-    path = None
-
-    def __init__(self):
-        # Список действий зарегистрированных на исполнение в данном пакете
-        self.actions = []
-        # Список дочерних пакетов (подпакетов),
-        # зарегистрированных на исполнение в данном пакете
-        self.subpacks = []
+    @property
+    @_cached_to('__cached_short_name')
+    def short_name(self):
+        # имя пака для поиска в ControllerCache в виде атрибута
+        # для совместимости с m3
+        return self.get_short_name()
 
     @classmethod
     def absolute_url(cls):
@@ -579,11 +659,47 @@ class ActionPack(object):
                 break
         return contr_url + url
 
+    #: Ссылка на вышестоящий пакет, тот в котором зарегистрирован данный пакет
+    parent = None
+
+    #: Ссылка на родительский ActionController
+    controller = None
+
+    #: Наименование Набора действий для отображения
+    verbose_name = None
+
+    #: Признак обработки прав доступа,
+    #: при выполнении дочерних действий (по-умолчанию отключен)
+    #: Как обрабатывается этот признак - смотри в Action.has_permission
+    need_check_permission = False
+
+    #: Словарь внутренних прав доступа, используемых в наборе действий
+    #: ключ - код права, который совмещается с адресом (кодом) набора действий
+    #: значение - наименование права
+    #: Пример: {'edit':u'Редактирование записи'}
+    #: Общий код права доступа будет иметь вид: /users#edit
+    #: Как обрабатывается этот список - смотри в has_sub_permission
+    sub_permissions = {}
+
+    #: Логический путь набора действий в прикладной системе.
+    #: Используется только для отображения
+    #: и группировке наборов с одинаковым путем.
+    #: Также может использоваться для создания меню.
+    #: Например, путь может быть: "Справочники\Общие" или "Реестры"
+    path = None
+
+    def __init__(self):
+        #: Список действий зарегистрированных на исполнение в данном пакете
+        self.actions = []
+        #: Список дочерних пакетов (подпакетов),
+        #: зарегистрированных на исполнение в данном пакете
+        self.subpacks = []
+
     def get_absolute_url(self):
         """
         Возвращает абсолютный путь (НОРМАЛЬНО, в отличие от absolute_url)
         """
-        assert hasattr(self, 'controller')
+        assert self.controller
         pack = self
         if pack.parent:
             path = []
@@ -604,6 +720,7 @@ class ActionPack(object):
 
     def has_sub_permission(self, user_obj, sub_code, request):
         # метод оставлен для совместимости
+
         return self.has_perm(request, sub_code)
 
     #================= НОВЫЙ ИНТЕРФЕЙС ПРОВЕРКИ ПРАВ ==========================
@@ -612,6 +729,9 @@ class ActionPack(object):
         Интерфейсный метод проверки подправ пака.
 
         Использовать ВМЕСТО has_sub_permission
+
+        :param request: запрос
+        :type request: django.http.Request
         """
         return _permission_checker.has_pack_permission(
             request, self, permission)
@@ -627,10 +747,17 @@ class ActionPack(object):
     def pre_run(self, request, context):
         """
         Метод для предварительной обработки
-        входящего запроса *request* и контекста *context*
+        входящего запроса и контекста
         перед передачений в нижестоящий экшен или пак.
         Если возвращает значение отличное от None, обработка запроса
         прекращается и результат уходит во вьюшку контроллера.
+
+        :param request: запрос
+        :type request: django.http.Request
+
+        :param context: Контекст выполнения операции, восстанавливаемый
+            из контекств
+        :type context: m3_core.actions.context.ActionContext
         """
         pass
 
@@ -639,11 +766,27 @@ class ActionPack(object):
         Метод для постобработки результата работы вышестоящего экшена или пака.
         Принимает исходный запрос *request*, результат работы *response* и
         извлеченный контекст *context*.
+
+        :param request: запрос
+        :type request: django.http.Request
+
+        :param context: Контекст выполнения операции, восстанавливаемый
+            из контекств
+        :type context: m3_core.actions.context.ActionContext
+
+        :param response: ответ, полученный в результате выполнения
+            действия
+        :type response: m3_core.actions.results.ActionResult
         '''
         pass
 
     @classmethod
     def get_verbose_name(cls):
+        """
+        Получение понятного имени пака
+
+        :rtype: unicode
+        """
         return (
             cls.title if hasattr(cls, 'title') and cls.title
             else cls.verbose_name if cls.verbose_name else cls.__name__
@@ -656,8 +799,7 @@ class ActionController(object):
     пользовательских запросов путем передачи
     их на исполнение соответствущим Action'ам
     '''
-
-    # Наименование Контроллера для отображения
+    #: Наименование Контроллера для отображения
     verbose_name = None
 
     class FakePacks:
@@ -671,14 +813,15 @@ class ActionController(object):
         def extend(self, items_list):
             pass
 
-    def __init__(self, url='', name=None):
+    def __init__(self, url="", name=None):
         '''
-        url - используется для отсечения лишней части пути в запросе, поскольку
-              управление в пак передается из вьюшки
-        name - человеческое название контроллера. Используется для отладки.
+        :param basetring url: используется для отсечения лишней части пути в
+            запросе, поскольку управление в пак передается из вьюшки
+        :param basestring name: человеческое название контроллера.
+            Используется для отладки.
         '''
-        # ДЛЯ СОВМЕСТИМОСТИ.
-        # Имитирует список паков торчащий наружу
+        #: ДЛЯ СОВМЕСТИМОСТИ.
+        #: Имитирует список паков торчащий наружу
         self.packs = self.FakePacks()
         self.packs.append = self.append_pack
         self.packs.extend = self.extend_packs
@@ -699,6 +842,7 @@ class ActionController(object):
         self._packs_by_type = {}
         self._actions_by_type = {}
         self._actions_by_name = {}
+        self._nodes_by_perm = {}
         # TODO: Тоже самое можно добавить для short_name
         # в экшенах вместо m3.helpers.urls
 
@@ -722,14 +866,16 @@ class ActionController(object):
     def _add_action_to_search_dicts(self, action, full_path):
         """ Добавляет экшен в словари для быстрого доступа """
         assert isinstance(action, Action)
-        self._actions_by_name[action.__class__.__name__] = (action, full_path)
+        self._actions_by_name[action.get_short_name()] = (action, full_path)
         self._actions_by_type[action.__class__] = (action, full_path)
+        self._nodes_by_perm[action.get_perm_code()] = action
 
     def _add_pack_to_search_dicts(self, pack):
         """ Добавляет экшенпак в словари для быстрого доступа """
         assert isinstance(pack, ActionPack)
-        self._packs_by_name[pack.__class__.__name__] = pack
+        self._packs_by_name[pack.get_short_name()] = pack
         self._packs_by_type[pack.__class__] = pack
+        self._nodes_by_perm[pack.get_perm_code()] = pack
 
     def _rebuild_search_dicts(self):
         """
@@ -801,8 +947,10 @@ class ActionController(object):
     def _invoke(self, request, action, stack):
         '''
         Непосредственный вызов экшена с отработкой всех событий
+
+        :param request: запрос
+        :type request: django.http.Request
         '''
-        from m3 import ApplicationLogicException
 
         # проверим что права на выполнение есть
         allowed = _permission_checker.has_action_permission(request, action)
@@ -874,6 +1022,14 @@ class ActionController(object):
         """
         Обработка входящего запроса *request* от клиента.
         Обрабатывается по аналогии с UrlResolver'ом Django
+
+        :param request: запрос
+        :type request: django.http.Request
+
+        :return: результат выполнения экшена
+        :rtype: наследник m3_core.actions.results.ActionResult
+
+        :raise: http.Http404
         """
         ControllerCache.populate()
 
@@ -916,6 +1072,15 @@ class ActionController(object):
         '''
         Выполняет построение контекста вызова операции ActionContext
         на основе переданного request
+
+        :param request: запрос
+        :type request: django.http.Request
+
+        :param dict rules: построение контекста
+
+        :return: пустой экземпляр контекста
+        :rtype: m3_core.actions.context.DeclarativeActionContext()
+            или m3_core.actions.context.ActionContext
         '''
         if isinstance(rules, dict):
             return DeclarativeActionContext()
@@ -925,39 +1090,31 @@ class ActionController(object):
     #==========================================================================
     # Методы, предназначенные для поиска экшенов и паков в контроллере
     #==========================================================================
+    @_must_be_replaced_by('ControllerCache.find_pack')
     def find_pack(self, type):
-        """
-        Ищет экшенпак класса *type* внутри иерархии котроллера.
-        Возвращает его экземпляр или None если не находит.
-        *type* может быть классом или строкой с названием класса,
-        это позволяет избежать кроссимпортов.
-        """
-        ControllerCache.populate()
-
-        if isinstance(type, basestring):
-            return self._packs_by_name.get(type)
-        elif issubclass(type, ActionPack):
-            return self._packs_by_type.get(type)
-        else:
-            raise ValueError('Wrong type of argument %s' % type)
+        return self._find_pack(type)
 
+    @_must_be_replaced_by('ControllerCache.find_action')
     def find_action(self, type):
-        """
-        Ищет экшен класса *type* внутри иерархии котроллера.
-        Возвращает его экземпляр или None если не находит.
-        *type* может быть классом или строкой с названием класса,
-        это позволяет избежать кроссимпортов.
-        """
-        ControllerCache.populate()
+        return self._find_action(type)
 
-        if isinstance(type, basestring):
-            clazz, _ = self._actions_by_name.get(type, (None, None))
-        elif issubclass(type, Action):
-            clazz, _ = self._actions_by_type.get(type, (None, None))
+    def _find_pack(self, pack):
+        if isinstance(pack, basestring):
+            inst = self._packs_by_name.get(pack)
+        elif inspect.isclass(pack):
+            inst = self._packs_by_type.get(pack)
         else:
-            raise ValueError('Wrong type of argument %s' % type)
+            raise ValueError('Wrong type of argument %s' % pack)
+        return inst
 
-        return clazz
+    def _find_action(self, action):
+        if isinstance(action, basestring):
+            inst, _ = self._actions_by_name.get(action, (None, None))
+        elif inspect.isclass(action):
+            inst, _ = self._actions_by_type.get(action, (None, None))
+        else:
+            raise ValueError('Wrong type of argument %s' % action)
+        return inst
 
     def get_action_url(self, type):
         """
@@ -974,33 +1131,45 @@ class ActionController(object):
 
         return full_path
 
+    def _find_node_by_perm(self, perm):
+        """
+        Возвращает экшн/пак по коду права
+        """
+        return self._nodes_by_perm.get(perm)
+
     #==========================================================================
     # Методы, предназначенные для добавления/изменения/удаления
     # пакетов действий в контроллер
     #==========================================================================
     def append_pack(self, pack):
-        """ Добавляет *pack*, объект типа ActionPack, в контроллер. """
-        # нам обязательно нужен экземпляр класса
-        # этот метод повторяется кучу раз
-        if isinstance(pack, str):
-            cleaned_pack = self._load_class(pack)()
-        elif inspect.isclass(pack):
-            cleaned_pack = pack()
-        else:
-            cleaned_pack = pack
+        """
+        Добавляет пак в контроллер.
 
-        self._build_pack_node(cleaned_pack, [])
+        :param pack: пак, который добавляется в контроллер
+        :type pack: m3_core.actions.ActionPack
+        """
+        if not isinstance(pack, ActionPack):
+            raise TypeError(
+                u'Pack must be an instance of ActionPack subclass!')
 
-        if cleaned_pack not in self.top_level_packs:
-            self.top_level_packs.append(cleaned_pack)
-            cleaned_pack.controller = self
+        # пак может быть перегруже
+        if pack.short_name in ControllerCache.overrides:
+            pack = ControllerCache.overrides[pack.short_name]
+
+        self._build_pack_node(pack, [])
+        if pack not in self.top_level_packs:
+            self.top_level_packs.append(pack)
+            pack.controller = self
         ControllerCache.register_controller(self)
+        return pack
 
     def extend_packs(self, packs):
         '''
         Производит массовое добавление экшенпаков в контроллер.
-        @param packs: список объектов типа ActionPack,
-        которые необходимо зарегистрировать в контроллере
+
+        :param packs: список паков,
+            которые необходимо зарегистрировать в контроллере
+        :type packs: список объектов m3_core.actions.ActionPack
         '''
         for pack in packs:
             self.append_pack(pack)
@@ -1033,23 +1202,28 @@ class ActionController(object):
         Вставляет экшенпак wrap_pack внутрь иерархии перед dest_pack.
         Таким образом можно перехватывать запросы и ответы пака dest_pack.
 
-        Допустим есть цепочка паков:
-           A1 - X - A2 - A3    |   A1 - Y - X - A2 - A3
-           B1 - B2 - X         |   B1 - B2 - Y - X
-           X - C1 - C2         |   Y - X - C1 - C2
-        Для решения нужно:
-        1. Найти экземпляры пака X
-        2. В цепочку вместо X вставить Y->X c учетом левых и правых участников
-        3. Перестроить адреса пробежавшись по цепочке
 
-        @param dest_pack: Пак который будем оборачивать
-        @param wrap_pack: Оборачивающий пак
+        :param dest_pack: Пак который будем оборачивать
+        :type dest_pack: m3_core.actions.ActionPack
+
+        :param wrap_pack: Оборачивающий пак
+        :type wrap_pack: m3_core.actions.ActionPack
         '''
         assert (
             issubclass(dest_pack, ActionPack) and
             issubclass(wrap_pack, ActionPack)
         )
 
+        """
+        Допустим есть цепочка паков:
+        A1 - X - A2 - A3    |   A1 - Y - X - A2 - A3
+        B1 - B2 - X         |   B1 - B2 - Y - X
+        X - C1 - C2         |   Y - X - C1 - C2
+        Для решения нужно:
+        1. Найти экземпляры пака X
+        2. В цепочку вместо X вставить Y->X c учетом левых и правых участников
+        3. Перестроить адреса пробежавшись по цепочке
+        """
         wrapper = wrap_pack()
         self._add_pack_to_search_dicts(wrapper)
         new_patterns = {}
@@ -1128,9 +1302,14 @@ class ActionController(object):
         Оборачивающий пак можно наследовать от оригинального,
         но тогда вместо оборачивая целесообразно использовать подмену паков.
 
-        @param dest_pack: Пак в который входит оборачиваемый экшен
-        @param dest_action: Оборачиваемый экшен
-        @param wrap_pack: Оборачивающий пак
+        :param dest_pack: Пак в который входит оборачиваемый экшен
+        :type dest_pack: m3_core.actions.ActionPack
+
+        :param dest_action: Оборачиваемый экшен
+        :type dest_action: m3_core.actions.Action
+
+        :param wrap_pack: Оборачивающий пак
+        :type wrap_pack: m3_core.actions.ActionPack
         '''
         assert (
             issubclass(dest_pack, ActionPack) and
@@ -1222,7 +1401,7 @@ class ActionController(object):
 
     def reset(self):
         '''
-        HARD RESET всего что наделал контроллер с паками и экшенами
+        Сброс всего, что наделал контроллер с паками и экшенами
         '''
         for pack in self.top_level_packs:
             if hasattr(pack, '_built'):
@@ -1249,6 +1428,8 @@ class ControllerCache(object):
     # словарь зарегистрированных контроллеров в прикладном приложении
     _controllers = set()
 
+    overrides = {}
+
     #==========================================================================
     # Методы, предназначенные для поиска экшенов
     # и паков во всех контроллерах системы
@@ -1267,24 +1448,51 @@ class ControllerCache(object):
     @classmethod
     def find_pack(cls, pack):
         """
-        Ищет заданный *pack* по имени класса или классу
+        Ищет заданный пак по имени класса или классу
         во всех зарегистрированных контроллерах.
         Возвращает экземпляр первого найденного пака.
+
+        :param pack: имя класса или класс пака
+        :type pack: строка формата package.Class или класс
+
+        :return: экземпляр найденного пака
+        :rtype: m3_core.actions.ActionPack
         """
-        for cont in list(cls._controllers):
-            p = cont.find_pack(pack)
-            if p:
-                return p
+        if inspect.isclass(pack):
+            name = pack.get_short_name()
+        elif isinstance(pack, str) and '.' in pack:
+            name = pack
+        else:
+            raise ValueError(
+                u'Pack must be a class or a string '
+                u'like "package.subpackage.Class"'
+            )
+
+        cls.populate()
+        over = cls.overrides.get(name)
+        if over:
+            return over
+        else:
+            for cont in list(cls._controllers):
+                p = cont._find_pack(pack)
+                if p:
+                    return p
 
     @classmethod
     def find_action(cls, action):
         """
-        Ищет заданный *action* по имени класса или классу
+        Ищет заданный экшен по имени класса или классу
         во всех зарегистрированных контроллерах.
         Возвращает экземпляр первого найденного экшена.
+
+        :param action: имя класса или класс экшена
+        :type action: строка формата package.Class или класс
+
+        :return: экземпляр найденного пака
+        :rtype: m3_core.actions.Action
         """
         for cont in list(cls._controllers):
-            p = cont.find_action(action)
+            p = cont._find_action(action)
             if p:
                 return p
 
@@ -1295,7 +1503,19 @@ class ControllerCache(object):
             act = cont.get_action_by_url(url)
             if act:
                 return act
-        return
+
+    @classmethod
+    def find_node_by_perm(cls, perm):
+        """
+        Возвращает экшн/пак по коду права, или None,
+        если таковых не найдено
+        :param string perm: код права
+        :return: экземпляр найденного пара/экшна
+        """
+        for cont in cls._controllers:
+            node = cont._find_node_by_perm(perm)
+            if node:
+                return node
 
     #==========================================================================
     @classmethod
@@ -1318,7 +1538,7 @@ class ControllerCache(object):
         def shortname_checker(acc):
             def check(obj, name):
                 sn = getattr(obj, 'shortname', None) or getattr(
-                        obj, 'shortname', None)
+                    obj, 'shortname', None)
                 if sn:
                     name = acc.get(sn)
                     if name:
@@ -1365,7 +1585,6 @@ class ControllerCache(object):
 
         return result
 
-
     @classmethod
     def register_controller(cls, controller):
         '''
@@ -1380,8 +1599,11 @@ class ControllerCache(object):
         Загружает в кэш ActionController'ы
         из перечисленных в INSTALLED_APPS приложений.
         В каждом из них загружает модуль *app_meta*
-        и пытается выполнить метод *register_actinos* внутри него.
+        и пытается выполнить метод *register_actions* внутри него.
         Выполняется только один раз. Возвращает истину в случае успеха.
+
+        :return: флаг успешного завершения
+        :rtype: boolean
         """
         if cls._loaded:
             return False
@@ -1389,7 +1611,9 @@ class ControllerCache(object):
         try:
             if cls._loaded:
                 return False
-            # Из инитов всех приложения пытаемся выполнить register_ui_actions
+
+            cls.overrides = {}
+            procs = []
             for app_name in settings.INSTALLED_APPS:
                 try:
                     module = import_module('.app_meta', app_name)
@@ -1397,9 +1621,24 @@ class ControllerCache(object):
                     if err.args[0].find('No module named') == -1:
                         raise
                     continue
+
+                # расширение словаря overridde'ов
+                for original_cls, new_inst in (
+                    getattr(module, 'action_pack_overrides', {}).iteritems()
+                ):
+                    if inspect.isclass(original_cls):
+                        original_cls = original_cls.get_short_name()
+                    cls.overrides[original_cls] = new_inst
+
+                # получение ф-ции - регистратора паков
                 proc = getattr(module, 'register_actions', None)
                 if callable(proc):
-                    proc()
+                    procs.append(proc)
+
+            # собственно, регистрируем экшны
+            for proc in procs:
+                proc()
+
             cls._loaded = True
         finally:
             cls._write_lock.release()
