@@ -168,8 +168,7 @@ class ListEditRowWindowAction(Action):
         win.form.url = base.save_row_action.get_absolute_url()
 
         # проверим право редактирования
-        if not self.parent.has_sub_permission(
-                request.user, self.parent.PERM_EDIT, request):
+        if not self.parent.has_permission(request, self.parent.PERM_EDIT):
             win.make_read_only(
                 access_off=True, exclude_list=['cancel_btn', 'close_btn'])
 
@@ -227,8 +226,7 @@ class TreeEditNodeWindowAction(Action):
         win.form.url = base.save_node_action.get_absolute_url()
 
         # проверим право редактирования
-        if not self.parent.has_sub_permission(
-                request.user, self.parent.PERM_EDIT, request):
+        if not self.parent.has_permission(request, self.parent.PERM_EDIT):
             win.make_read_only(
                 access_off=True, exclude_list=['close_btn', 'cancel_btn'])
 
@@ -411,8 +409,7 @@ class ListWindowAction(Action):
         win = self.parent.get_list_window(win)
 
         # проверим право редактирования
-        if not self.parent.has_sub_permission(
-                request.user, self.parent.PERM_EDIT, request):
+        if not self.parent.has_permission(request, self.parent.PERM_EDIT):
             win.make_read_only()
 
         return ExtUIScriptResult(win)
@@ -436,24 +433,13 @@ class SelectWindowAction(ListWindowAction):
         self.configure_list(win, request, context)
         self.configure_tree(win, request, context)
 
-        # Ожидается в далеком будущем ;)
-        #win.column_name_on_select = 'fname'
-        #win.list_view.add_column(header=u'Имя', data_index = 'fname')
-        #win.list_view.add_column(header=u'Фамилия', data_index = 'lname')
-        #win.list_view.add_column(header=u'Адрес', data_index = 'adress')
-        # Заглушка, иначе ругается что нет стора
-        win.list_view.set_store(ExtJsonStore(
-            url='/ui/grid-json-store-data', auto_load=False))
-
-        #win.column_name_on_select = 'name'
         win.column_name_on_select = base.column_name_on_select
 
         win = self.parent.get_select_window(win)
         win.contextTreeIdName = base.contextTreeIdName
 
         # проверим право редактирования
-        if not self.parent.has_sub_permission(
-                request.user, self.parent.PERM_EDIT, request):
+        if not self.parent.has_perm(request, self.parent.PERM_EDIT):
             win.make_read_only()
 
         return ExtUIScriptResult(win)
