@@ -1,6 +1,7 @@
 #coding:utf-8
 '''
 Паки для иерархических справочников
++++++++++++++++++++++++++++++++++++
 '''
 
 from django.db import transaction
@@ -25,6 +26,7 @@ class TreeGetNodesAction(Action):
     Вызывает функцию получения узлов дерева у родительского пака
     '''
     url = '/nodes$'
+
     def run(self, request, context):
         parent_id = utils.extract_int(request, 'node')
         if parent_id < 1:
@@ -33,6 +35,7 @@ class TreeGetNodesAction(Action):
         result = self.parent.get_nodes(parent_id, filter)
         return PreJsonResult(result)
 
+
 class TreeGetNodesLikeRows(Action):
     '''
     Возвращает узлы дерева как список. Используется для автокомплита.
@@ -40,11 +43,15 @@ class TreeGetNodesLikeRows(Action):
     url = '/nodes_like_rows$'
 
     def context_declaration(self):
-        return [ActionContextDeclaration(name='filter', default='', type=str, required=True),
-                ActionContextDeclaration(name='branch_id', default=0, type=int, required=True)]
+        return [
+            ActionContextDeclaration(
+                name='filter', default='', type=str, required=True),
+            ActionContextDeclaration(
+                name='branch_id', default=0, type=int, required=True)]
 
     def run(self, request, context):
-        result = self.parent.get_nodes_like_rows(context.filter, context.branch_id)
+        result = self.parent.get_nodes_like_rows(
+            context.filter, context.branch_id)
         return PreJsonResult(result)
 
 
@@ -53,6 +60,7 @@ class TreeGetNodeAction(Action):
     Вызывает функцию получения узла дерева (нужно для редактирования в карточке)
     '''
     url = '/node$'
+
     def context_declaration(self):
         return [ACD(name='id', default=0, type=int, required=True, verbose_name=u'id группы справочника')]
 
@@ -63,11 +71,13 @@ class TreeGetNodeAction(Action):
             return OperationResult.by_message(MSG_DOESNOTEXISTS % context.id)
         return PreJsonResult(result)
 
+
 class TreeSaveNodeAction(Action):
     '''
     Вызывает функцию сохранения узла дерева.
     '''
     url = '/save_node$'
+
     def context_declaration(self):
         return [ACD(name='id', default=0, type=int, required=True, verbose_name=u'id группы справочника')]
 
@@ -179,7 +189,7 @@ class ListEditRowWindowAction(Action):
         win.form.url = base.save_row_action.get_absolute_url()
 
         # проверим право редактирования
-        if not self.parent.has_sub_permission(request.user, self.parent.PERM_EDIT, request):
+        if not self.parent.has_perm(request, self.parent.PERM_EDIT):
             win.make_read_only(access_off=True, exclude_list=['cancel_btn','close_btn'])
 
         # У окна может быть процедура доп. конфигурации под конкретный справочник
@@ -238,7 +248,7 @@ class TreeEditNodeWindowAction(Action):
         win.form.url = base.save_node_action.get_absolute_url()
 
         # проверим право редактирования
-        if not self.parent.has_sub_permission(request.user, self.parent.PERM_EDIT, request):
+        if not self.parent.has_perm(request, self.parent.PERM_EDIT):
             win.make_read_only(access_off = True, exclude_list = ['close_btn','cancel_btn'])
 
         # У окна может быть процедура доп. конфигурации под конкретный справочник
@@ -396,7 +406,7 @@ class ListWindowAction(Action):
         win = self.parent.get_list_window(win)
 
         # проверим право редактирования
-        if not self.parent.has_sub_permission(request.user, self.parent.PERM_EDIT, request):
+        if not self.parent.has_perm(request, self.parent.PERM_EDIT):
             win.make_read_only()
 
         return ExtUIScriptResult(win)
@@ -415,22 +425,13 @@ class SelectWindowAction(ListWindowAction):
         self.configure_list(win, request, context)
         self.configure_tree(win, request, context)
 
-        # Ожидается в далеком будущем ;)
-        #win.column_name_on_select = 'fname'
-        #win.list_view.add_column(header=u'Имя', data_index = 'fname')
-        #win.list_view.add_column(header=u'Фамилия', data_index = 'lname')
-        #win.list_view.add_column(header=u'Адрес', data_index = 'adress')
-        # Заглушка, иначе ругается что нет стора
-        win.list_view.set_store(ExtJsonStore(url='/ui/grid-json-store-data', auto_load=False))
-
-        #win.column_name_on_select = 'name'
         win.column_name_on_select = base.column_name_on_select
 
         win = self.parent.get_select_window(win)
         win.contextTreeIdName = base.contextTreeIdName
 
         # проверим право редактирования
-        if not self.parent.has_sub_permission(request.user, self.parent.PERM_EDIT, request):
+        if not self.parent.has_perm(request, self.parent.PERM_EDIT):
             win.make_read_only()
 
         return ExtUIScriptResult(win)
